@@ -1,6 +1,8 @@
 # -*- coding: utf-8 -*-
 """Asyncify"""
-from asyncify._meta import __version__
+from __future__ import annotations
+
+from asyncify.__about__ import __version__
 from asyncify.core import (
     ANYIO,
     aiorun,
