@@ -1,8 +1,10 @@
 # -*- coding: utf-8 -*-
 """Asyncify core"""
 
+from __future__ import annotations
+
 import asyncio
-import sys
+import warnings
 
 from asyncio import AbstractEventLoop, get_event_loop, run as asyncio_run
 from functools import partial, wraps
@@ -62,7 +64,7 @@ except ImportError:  # pragma: no cover
     ) -> Callable[P, Awaitable[T]]:
         raise ImportError("install anyio; `pip install anyio`")
 
-    def anyio_run(
+    def anyio_run(  # type: ignore[misc]
         func: Callable[..., Coroutine[Any, Any, T_Retval]],
         *args: object,
         backend: str = "asyncio",
@@ -104,7 +106,7 @@ def aiterable(it: Union[Iterable[T], AsyncIterable[T]]) -> AsyncIterator[T]:
         return it.__aiter__()
 
     async def gen() -> AsyncIterator[T]:
-        for item in cast(Iterable[T], it):
+        for item in it:
             yield item
 
     return gen()
@@ -120,6 +122,8 @@ def asyncify(
 
     Args:
         funk: Function to make into an async coroutine
+        loop: Event loop in which to run/execute
+        executor: Executor to with which to execute
 
     Returns:
         An asynchronous function
@@ -143,8 +147,8 @@ def asyncify(
 
     @wraps(funk)
     async def _async_funk(
-        *args: P.args,  # type: ignore
-        **kwargs: P.kwargs,  # type: ignore
+        *args: P.args,
+        **kwargs: P.kwargs,
     ) -> T:
         """Async wrapper function
 
@@ -159,7 +163,7 @@ def asyncify(
 
         """
         loop = _loop if _loop else get_event_loop()
-        pfunc: Callable[P, T] = partial(funk, *args, **kwargs)
+        pfunc: Callable[[], T] = partial(funk, *args, **kwargs)
         return await loop.run_in_executor(_executor, pfunc)
 
     return cast(Callable[P, Awaitable[T]], _async_funk)
@@ -198,7 +202,9 @@ def _run(aw: Awaitable[T], *, debug: Optional[bool] = None) -> T:
         asyncio.set_event_loop(None)
 
 
-def run(aw: Awaitable[T], *, debug: Optional[bool] = None, **kwargs: Any) -> T:
+def run(
+    aw: Coroutine[Any, Any, T], *, debug: Optional[bool] = None, **kwargs: Any
+) -> T:
     """Run an async/awaitable function (Polyfill asyncio.run)
 
     Emulate `asyncio.run()` for snakes below python 3.7; `asyncio.run` was
@@ -207,6 +213,7 @@ def run(aw: Awaitable[T], *, debug: Optional[bool] = None, **kwargs: Any) -> T:
     Args:
         aw (Awaitable[T]): Async/awaitable function to run
         debug (Optional[bool]): If True run event loop in debug mode
+        **kwargs: keyword arguments to be passed to the wrapped function
 
     Returns:
         T: Return the result of running the async function
@@ -220,9 +227,15 @@ def run(aw: Awaitable[T], *, debug: Optional[bool] = None, **kwargs: Any) -> T:
         5
 
     """
-    if sys.version_info >= (3, 7):
-        return asyncio.run(aw, debug=debug)
-    return _run(aw=aw, debug=debug)  # pragma: no cover
+    # If python is 3.6
+    if not hasattr(asyncio, "run"):  # pragma: no cover
+        warnings.warn(
+            "asyncify no longer supports python3.6...",
+            DeprecationWarning,
+            stacklevel=2,
+        )
+        return _run(aw, debug=debug)
+    return asyncio_run(aw, debug=debug)
 
 
 def is_async(obj: Any) -> bool:
@@ -247,7 +260,7 @@ def is_async(obj: Any) -> bool:
     return asyncio.iscoroutinefunction(obj) or asyncio.iscoroutine(obj)
 
 
-def is_coro(obj: Any) -> TypeGuard[Awaitable]:
+def is_coro(obj: Any) -> TypeGuard[Awaitable[Any]]:
     return asyncio.iscoroutine(obj)
 
 
@@ -264,7 +277,7 @@ async def await_or_return(obj: Union[Awaitable[T], T]) -> T:
         5
 
     """
-    return await obj if isawaitable(obj) else obj  # type: ignore
+    return cast(T, await obj if isawaitable(obj) else obj)
 
 
 def aiorun_anyio(
@@ -275,8 +288,18 @@ def aiorun_anyio(
     backend: str = "asyncio",
     backend_options: Optional[Dict[str, Any]] = None,
 ) -> T_Retval:
-    # if asyncio.iscoroutine(awaitable_or_func):
-    # if asyncio.iscoroutine(awaitable_or_func):
+    """Run an async function or awaitable using anyio
+
+    Args:
+        awaitable_or_func: Function or awaitable to run
+        *args: args to pass to the function
+        backend: Backend to use for running the function
+        backend_options: Options to pass to the backend
+
+    Returns:
+        T_Retval: Return value of the function
+
+    """
     if is_coro(awaitable_or_func):
         if args:
             raise ValueError("args must be empty when calling a coroutine")
@@ -309,12 +332,15 @@ def aiorun_asyncio(
     _debug = _backend_options.get("debug", False)
     if callable(awaitable_or_func) and not asyncio.iscoroutine(awaitable_or_func):
         return asyncio_run(
-            cast(Awaitable[T_Retval], awaitable_or_func(*args)), debug=_debug
+            awaitable_or_func(*args),
+            debug=_debug,
         )
 
     if args:
         raise ValueError("args must be empty when calling a coroutine")
-    return asyncio_run(cast(Awaitable[T_Retval], awaitable_or_func), debug=_debug)
+    return asyncio_run(
+        cast(Coroutine[Any, Any, T_Retval], awaitable_or_func), debug=_debug
+    )
 
 
 def aiorun(
@@ -336,7 +362,7 @@ def aiorun(
     )
 
 
-if __name__ == "__main__":
+if __name__ == "__main__":  # pragma: no cover
     import doctest
 
     doctest.testmod()
